@@ -5,10 +5,10 @@ import random as _random
 import string as _string
 import os as _os
 
-from physicsLab._utf_8 import utf8_coding as _utf8_coding
+from ._utf_8 import utf8_coding as _utf8_coding
 import physicsLab._fileGlobals as _fileGlobals
-from electricity.element import crt_Element
-import electricity._elementPosition as _elementPosition
+from physicsLab.electricity.element import crt_Element
+import physicsLab.electricity._elementPosition as _elementPosition
 
 ### define ###
 
